/*
 * xmalloc.c
 *
 * This file is part of msmtp, an SMTP client.
 *
 * Copyright (C) 2004
 * Martin Lambers <marlam@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *   msmtp is released under the GPL with the additional exemption that
 *   compiling, linking, and/or using OpenSSL is allowed.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
extern int errno;

#ifdef HAVE_SYSEXITS_H
#include <sysexits.h>
#else
#define EX_OSERR	71
#endif


/*
 * xmalloc()
 */

void *xmalloc(size_t size)
{
    void *ptr;

    if (!(ptr = malloc(size))) 
    {
	fprintf(stderr, "FATAL: %s", strerror(errno));
	exit(EX_OSERR);
    }
    return ptr;
}


/* 
 * xcalloc()
 */

void *xcalloc(size_t n, size_t size)
{
    void *ptr;

    if (!(ptr = calloc(n, size)))
    {
	fprintf(stderr, "FATAL: %s", strerror(errno));
	exit(EX_OSERR);
    }
    return ptr;
}

    
/* 
 * xrealloc()
 */

void *xrealloc(void *ptr, size_t newsize)
{
    if (!(ptr = realloc(ptr, newsize)))
    {
	fprintf(stderr, "FATAL: %s", strerror(errno));
	exit(EX_OSERR);
    }
    return ptr;
}


/*
 * xstrdup()
 */

char *xstrdup(const char *s)
{
    char *p;

    if (!(p = strdup(s)))
    {
	fprintf(stderr, "FATAL: %s", strerror(errno));
	exit(EX_OSERR);
    }
    return p;
}
